/* Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved. */

/******************************************************************************
 *
 * You may not use the identified files except in compliance with the Apache
 * License, Version 2.0 (the "License.")
 *
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * NAME
 *   insert1.js
 *
 * DESCRIPTION
 *   Creates a table and inserts data.  Shows DDL and DML
 *
 *****************************************************************************/

var oracledb = require('oracledb');
var dbConfig = require('./dbconfig.js');

oracledb.getConnection(
  {
    user          : dbConfig.user,
    password      : dbConfig.password,
    connectString : dbConfig.connectString
  },
  function(err, connection)
  {
    if (err) {
      console.error(err.message);
      return;
    }
    connection.execute(
      "CREATE TABLE test (id NUMBER, name VARCHAR2(20))",
      function(err)
      {
        if (err) {
          console.error(err.message);
          return;
        }
        console.log("Table created");

        connection.execute(
          "INSERT INTO test VALUES (:id, :nm)",
          [1, 'Chris'],  // Bind values
          function(err, result)
          {
            if (err) { console.error(err.message); return; }
            console.log("Rows inserted: " + result.rowsAffected);  // 1

            connection.execute(
              "INSERT INTO test VALUES (:id, :nm)",
              [2, 'Alison'],  // Bind values
              function(err, result)
              {
                if (err) { console.error(err.message); return; }
                console.log("Rows inserted: " + result.rowsAffected);  // 1

                connection.execute(
                  "UPDATE test SET name = 'Bambi'",
                  function(err, result)
                  {
                    if (err) { console.error(err.message); return; }
                    console.log("Rows updated: " + result.rowsAffected); // 2
                    
                    connection.execute(
                      "DROP TABLE test",
                      function(err)
                      {
                        if (err) { console.error(err.message); return; }
                        console.log("Table dropped");
                        
                        connection.release(
                          function(err)
                          {
                            if (err) { console.error(err.message); return; }
                          });
                      });
                  });
              });
          });
      });
  });
